Use the geometry builder to programmatically create geometries. No optimization are performed by the geometry builder on the input data.

To programmatically build a geometry for immediate display see [ModelBuilder] to directly build models.